@@ -1,4 +1,4 @@
-/* $Id: dccm.c,v 1.16 2003/12/22 13:07:51 twogood Exp $ */
+/* $Id: dccm.c,v 1.18 2004/07/09 05:23:55 twogood Exp $ */
 #include <synce_socket.h>
 #include <synce_log.h>
 #include <stdbool.h>
@@ -511,6 +511,12 @@ static bool client_read(Client* client)
 
 		synce_trace("this is a password challenge");
 
+    if (!password)
+    {
+      synce_error("A password is needed to connect to this device, but it was not supplied on the dccm command line.");
+      goto exit;
+    }
+
 		if (!synce_password_send(client->socket, password, client->key))
 		{
 			synce_error("failed to send password");
@@ -565,8 +571,11 @@ static bool client_handler(Client* client)
 					goto exit;	
 				}
 
-				if (!password_correct)
-					goto exit;
+        if (!password_correct)
+        {
+          synce_error("The password supplied on the dccm comand line was not correct!");
+          goto exit;
+        }
 
         if (!synce_socket_write(client->socket, &ping, sizeof(ping)))
         {
@@ -697,7 +706,7 @@ int main(int argc, char** argv)
 
 	if (!allow_root && 0 == getuid())
 	{
-		synce_error("You should not run dccm as root.");
+		synce_error("You should not run dccm as root. Terminating immediately.");
 		goto exit;
 	}
 
